<?php

/**
 * Report Plugin Migrations Pending.
 */
function srm_admin_notice_migrations_pending() {
	if ( get_transient( 'srm_pending_migrations' ) && ! empty( get_transient( 'srm_pending_migrations' ) ) ) {
        $message            = __( 'Starfish Reviews needs to perform updates to the database', 'starfish' );
        $sub_message        =  __( 'Pending Updates:', 'starfish' );
        $instructions       = __( 'Click the button to allow Starfish to automatically perform these updates', 'starfish' );
        $pending_migrations = null;
        foreach ( SRM_MIGRATIONS::get_pending() as $migration ) {
            $pending_migrations .= '<p>[' . $migration->version . '] ' . $migration->name . ': ' . $migration->description . ' - ' . $migration->comment . '</p>';
        }
        $template_variables = array(
		    'content' => sprintf(
		    '<strong>%s</strong><br/>%s%s<button class="button-primary" id="srm-start-migrations">Update Now</button>&nbsp;&nbsp;<i>%s</i>',
            $message,
            $sub_message,
            $pending_migrations,
            $instructions
        ));

        $twig = SRM_TWIG::get_twig();
        echo $twig->render( 'starfish-admin-notice-warning.html.twig', $template_variables );
	}
}

add_action( 'admin_notices', 'srm_admin_notice_migrations_pending' );

/**
 * Report any failed Schema Migration.
 */
function srm_admin_notice_migrations_failed() {
	if ( get_transient( 'srm_failed_migrations' ) && ! empty( get_transient( 'srm_failed_migrations' ) ) ) {
	    $message           = __( 'The following Starfish Reviews migrations are currently in a FAILED status', 'starfish' );
        $failed_migrations = null;
        foreach ( SRM_MIGRATIONS::get_failures() as $migration ) {
            $failed_migrations .= '<p>[' . $migration->version . '] ' . $migration->name . ': ' . $migration->description . ' - ' . $migration->comment . '</p>';
        }
        $template_variables = array(
            'content' => sprintf(
                '<strong>%s</strong>%s',
                $message,
                $failed_migrations
            )
        );

        $twig = SRM_TWIG::get_twig();
        echo $twig->render( 'starfish-admin-notice-error.html.twig', $template_variables );
	}
}

add_action( 'admin_notices', 'srm_admin_notice_migrations_failed' );

/**
 * Report any successful Schema Migration.
 */
function srm_admin_notice_migrations_successful() {
	if ( get_transient( 'srm_successful_migrations' ) && ! empty( get_transient( 'srm_successful_migrations' ) ) ) {
		$migrations            = get_transient( 'srm_successful_migrations' );
		$message               = __( 'The following Starfish Reviews migrations completed successfully', 'starfish' );
		$successful_migrations = null;
        foreach ( $migrations as $migration ) {
            $successful_migrations .= '<p>[' . $migration->version . '] ' . $migration->name . ': ' . $migration->description . ' - ' . $migration->comment . '</p>';
        }
        $template_variables = array(
            'content' => sprintf(
                '<strong>%s</strong>',
		        $message,
                $successful_migrations
            )
        );

        $twig = SRM_TWIG::get_twig();
        echo $twig->render( 'starfish-admin-notice-info.html.twig', $template_variables );
	}
}

add_action( 'admin_notices', 'srm_admin_notice_migrations_successful' );

/**
 * Report PHP Version is not new enough.
 */
function srm_admin_notice_php_version() {
	if ( ! get_transient( 'srm_activation_php_check' ) && ! empty( get_transient( 'srm_activation_php_check' ) ) ) {
        deactivate_plugins( SRM_PLUGIN_BASENAME );

        $message = sprintf( __( 'In order to activate Starfish Reviews a PHP Version of %1$s or greater is required, currently PHP Version %2$s is found.', 'starfish' ), SRM_MINIMUM_PHP_VERSION, PHP_VERSION ) ;

		if ( isset( $_GET['activate'] ) ) {
			unset( $_GET['activate'] );
		}

        $template_variables = array(
            'content' => $message
        );

        $twig = SRM_TWIG::get_twig();
        echo $twig->render( 'starfish-admin-notice-error.html.twig', $template_variables );
	}
}

add_action( 'admin_notices', 'srm_admin_notice_php_version' );

/**
 * Present a friendly message showing how many new feedback records have been received recently
 *
 * @param $post_type
 *
 * @throws Freemius_Exception
 */
function srm_feedback_recent_records_message( $post_type ) {

    global $typenow;
    if ( SRM_FREEMIUS::starfish_fs()->can_use_premium_code() && 'starfish_feedback' === $typenow ) {
        $days_ago = 1;
        $feedback = SRM_FEEDBACK::srm_get_recent_feedback_count( $days_ago );
        if ( $feedback > 0 ) {
            $message = sprintf( __( 'You received <strong>%s</strong> new Feedback in the last <strong>%s</strong> day(s)<br/>Keep up the good work!', 'starfish' ), $feedback, $days_ago );

            $template_variables = array(
                'content' => $message
            );

            $twig = SRM_TWIG::get_twig();
            echo $twig->render( 'starfish-admin-notice-info.html.twig', $template_variables );
        }
    }

}

add_action( 'admin_notices', 'srm_feedback_recent_records_message' );
