/**
 * Funnel processing
 *
 * @package WordPress
 * @subpackage starfish
 * @version 2.1
 */

jQuery(function ($) {

	const funnelStepper = new Stepper(document.querySelector('#srm-funnel'), {
		linear: true,
		animation: false
	});

	$('#srm-funnel-positive').click(function () {
		log_decision(true);
	});

			$('#srm-funnel-negative').click(function () {
				log_decision(false);
			});

			if ('p' === getQueryParams().feedback) {
				log_decision(true);
			}

			if ('n' === getQueryParams().feedback) {
				log_decision(false);
			}

			function log_decision(decision) {
				// Create the initial funnel's feedback record
				const response = srm_create_feedback($, funnel_vars, decision);
				if (response) {
					if(decision) {
						funnelStepper.to(2);
						auto_redirect();
					}
					else {
						funnelStepper.to(3);
					}
				} else {
					$(`#srm-funnel-${funnel_vars.id}-1`).find('.srm-funnel-heading').html('<div class="srm-funnel-error">Failed to log decision</div>');
					$("#srm-funnel-questions").hide();
				}

				// Click the single destination
				$(".srm-funnel-single-submit").unbind("click").on("click", function() {
					const payload = {
						"feedback_id": $("#srm-funnel-feedback-id").text(),
						"destination_url": funnel_vars.destination_url,
						"destination_name": (new URL(funnel_vars.destination_url)).hostname
					};
					srm_update_feedback("single_destination", $, funnel_vars, decision, false, payload);
					window.location = funnel_vars.destination_url;
				});

				// Click a multi-destination
				$(".srm-funnel-multi-destination-submit").unbind("click").on("click", function() {
					const destinationUrl  = $(this).data("srm_desti_url");
					const destinationName = $(this).data("srm_desti_name");
					const payload = {
						"feedback_id": $("#srm-funnel-feedback-id").text(),
						"destination_url": destinationUrl,
						"destination_name": destinationName
					};
					srm_update_feedback("multi_destination", $, funnel_vars, decision, false, payload);
					window.location = destinationUrl;
				});

				// Click skip feedback form
				$("#srm-funnel-feedback-skip").unbind("click").on("click", function() {
					funnelStepper.to(5);
					const payload = {
						"feedback_id": $("#srm-funnel-feedback-id").text(),
						"reviewer_text": "-- Skipped Feedback --"
					};
					srm_update_feedback("skip_feedback", $, funnel_vars, decision, false, payload);
					auto_redirect();
				});

				// Click feedback form submit
				$("#srm-funnel-feedback-submit").unbind("click").on("click", function() {
					// Fetch all the forms we want to apply custom Bootstrap validation styles to
					var forms = document.getElementsByClassName('needs-validation');
					// Loop over them and prevent submission
					Array.prototype.filter.call(forms, function(form) {
						form.addEventListener('submit', function(event) {
							if (form.checkValidity() === false) {
								event.preventDefault();
								event.stopPropagation();
							}
							else {
								funnelStepper.to(4);
								const payload = {
									"feedback_id": $("#srm-funnel-feedback-id").text(),
									"reviewer_text": $("#srm-funnel-reviewer-text").val(),
									"reviewer_name": $("#srm-funnel-reviewer-name").val(),
									"reviewer_email": $("#srm-funnel-reviewer-email").val(),
									"reviewer_phone": $("#srm-funnel-reviewer-phone").val()
								};
								srm_update_feedback("submit_feedback", $, funnel_vars, decision, true, payload)
							}
							form.classList.add('was-validated');
						}, false);
					});
				});

			}

			function auto_redirect() {
				if ((funnel_vars.auto_redirect_seconds > 0) && ("single" === funnel_vars.destination_type)) {
					const autoForwardSeconds = funnel_vars.auto_redirect_seconds * 1000;
					setTimeout(
						function () {
							$(".srm-funnel-single-submit").hide();
							$(".srm-funnel-single-submit").trigger("click");
						},
						autoForwardSeconds
					);
				}
			}

		});
