<?php

/**
 * Plugin Name: Starfish Reviews
 * Plugin URI:  https://starfish.reviews
 * Description: The #1 review generation and review marketing plugin for WordPress! Encourage your tribe to provide 5-star reviews on Google, Facebook, and many more.
 * Author: Starfish Reviews
 * Version: 2.3.31
 * Author URI: https://starfish.reviews
 * Copyright: 2017 - 2019 Starfish
 * License: GPL2
 * License URI:
 * https://www.gnu.org/licenses/gpl-2.0.html
 * Text Domain: starfish
 *
 * @package         WordPress
 * @subpackage      starfish
 */
/**
 * --------------------------------------------
 * Verify expected path and functions exist
 * --------------------------------------------
 */
if ( !defined( 'ABSPATH' ) ) {
    exit;
}

if ( class_exists( 'SRM_FREEMIUS' ) ) {
    SRM_FREEMIUS::starfish_fs()->set_basename( false, __FILE__ );
    return;
}

/**
 * --------------------------------------------
 * Plugin Constants
 * --------------------------------------------
 */
define( 'SRM_VERSION', '2.3.31' );
define( 'SRM_MINIMUM_PHP_VERSION', '7.3.0' );
define( 'SRM_BUSINESS_PLAN', 'business' );
define( 'SRM_MARKETER_PLAN', 'marketer' );
define( 'SRM_WEBMASTER_PLAN', 'webmaster' );
define( 'SRM_PLANS_URL', 'https://starfish.reviews/plans-pricing' );
define( 'SRM_PLUGIN_URL', untrailingslashit( plugins_url( basename( plugin_dir_path( __FILE__ ) ), basename( __FILE__ ) ) ) );
define( 'SRM_MAIN_FILE', __FILE__ );
define( 'SRM_PLUGIN_PATH', plugin_dir_path( __FILE__ ) );
define( 'SRM_PLUGIN_BASENAME', plugin_basename( __FILE__ ) );
define( 'SRM_PLUGIN_ACTIVE', true );
// Plugin Option Groups!
define( 'SRM_OPTION_GROUP_GENERAL', 'srm_general_options' );
define( 'SRM_OPTION_GROUP_EMAIL', 'srm_email_options' );
define( 'SRM_OPTION_GROUP_DEFAULTS', 'srm_defaults_options' );
define( 'SRM_OPTION_GROUP_TOOLBOX', 'srm_toolbox_options' );
// Plugin Options!
define( 'SRM_OPTION_INSTALL_DATE', 'srm_install_date' );
define( 'SRM_OPTION_ALL_FUNNELS', 'srm_all_funnels' );
define( 'SRM_OPTION_FUNNEL_SLUG', 'srm_feedback_slug' );
define( 'SRM_OPTION_BRANDING', 'srm_branding' );
define( 'SRM_OPTION_REPLY_TO_EMAIL', 'srm_replay_to_email' );
define( 'SRM_OPTION_CLEAN_ON_DEACTIVATE', 'srm_clean_on_deactive' );
define( 'SRM_OPTION_AFFILLIATE_URL', 'srm_affiliate_url' );
define( 'SRM_OPTION_EMAIL_FROM_NAME', 'srm_email_from_name' );
define( 'SRM_OPTION_EMAIL_FROM_EMAIL', 'srm_email_from_email' );
define( 'SRM_OPTION_EMAIL_SUBJECT', 'srm_email_subject' );
define( 'SRM_OPTION_EMAIL_TEMPLATE', 'srm_email_template' );
define( 'SRM_OPTION_DEFAULT_FEEDBACK_EMAIL', 'srm_default_feedback_email' );
define( 'SRM_OPTION_MSG_NO_THANK_YOU', 'srm_msg_no_thank_you' );
define( 'SRM_OPTION_DEFAULT_NO_FEEDBACK_PROMPT', 'srm_default_no_review_prompt' );
define( 'SRM_OPTION_DEFAULT_REVIEW_PROMPT', 'srm_default_review_prompt' );
define( 'SRM_OPTION_DEFAULT_SUBMIT_BUTTON_NO', 'srm_default_submit_button_no' );
define( 'SRM_OPTION_DEFAULT_SUBMIT_BUTTON', 'srm_default_submit_button' );
define( 'SRM_OPTION_DEFAULT_YN_QUESTION', 'srm_default_yn_question' );
define( 'SRM_OPTION_YES_REDIRECT_SECONDS', 'srm_yes_redirect_seconds' );
define( 'SRM_OPTION_DEFAULT_PUBLIC_REVIEW_TEXT', 'srm_default_public_review_text' );
define( 'SRM_OPTION_DEFAULT_SKIP_FEEDBACK_TEXT', 'srm_default_skip_feedback_text' );
/**
 * Funnel Meta Data
 */
define( 'SRM_META_REVIEWER_NAME', '_srm_reviewer_name' );
define( 'SRM_META_REVIEWER_EMAIL', '_srm_reviewer_email' );
define( 'SRM_META_REVIEWER_PHONE', '_srm_reviewer_phone' );
define( 'SRM_META_REVIEWER_FEEDBACK', '_srm_feedback' );
define( 'SRM_META_FUNNEL_ID', '_srm_funnel_id' );
define( 'SRM_META_DESTI_NAME', '_srm_desti_name' );
define( 'SRM_META_TRACKING_ID', '_srm_tracking_id' );
// Plugin Migrations!
define( 'SRM_MIGRATIONS', 'srm_migrations' );
/**
 * --------------------------------------------
 * Include Classes
 * --------------------------------------------
 */
// Autoload Classes!
spl_autoload_register( function ( $class_name ) {
    if ( strpos( $class_name, 'SRM_' ) !== false ) {
        require_once 'classes/' . $class_name . '.class.php';
    }
} );
/**
 * --------------------------------------------
 * Initialize localization
 * --------------------------------------------
 */
function load_plugin_languages()
{
    // load plugin languages
    load_plugin_textdomain( 'starfish', false, basename( dirname( __FILE__ ) ) . '/languages/' );
}

add_action( 'init', 'load_plugin_languages', 0 );
/**
 * --------------------------------------------
 * Plugin Activation and Deactivation
 * --------------------------------------------
 */
require_once 'classes/SRM_FREEMIUS.class.php';
require_once 'classes/SRM_SETTINGS.class.php';
require_once 'classes/SRM_TWIG.class.php';
require_once 'init/starfish-activation.php';
require_once 'init/starfish-deactivation.php';
register_activation_hook( __FILE__, 'srm_plugin_install' );
register_deactivation_hook( __FILE__, 'srm_plugin_uninstall' );
define( 'SRM_PLAN_TITLE', SRM_FREEMIUS::starfish_fs()->get_plan_title() );
define( 'SRM_PLAN_LIMIT', SRM_FUNNELS::srm_get_plan_limit( SRM_PLAN_TITLE ) );
/**
 * --------------------------------------------
 * Included Actions
 * --------------------------------------------
 */
require_once 'init/actions/starfish-feedback-process.action.php';
require_once 'init/actions/starfish-ajax-callbacks.action.php';
require_once 'init/actions/starfish-admin-notices.action.php';
require_once 'init/actions/starfish-funnels.action.php';
require_once 'init/actions/starfish-feedback.action.php';
require_once 'init/actions/starfish-pluginloaded.action.php';
require_once 'init/actions/starfish-enqueue-scripts.action.php';
require_once 'init/actions/starfish-templates.action.php';
require_once 'init/actions/starfish-admin.action.php';
require_once 'init/actions/starfish-api-meta.action.php';
require_once 'init/actions/export/starfish-export-feedback.php';
/**
 * --------------------------------------------
 * Included Filters
 * --------------------------------------------
 */
require_once 'init/filters/starfish-action-links.filter.php';
require_once 'init/filters/starfish-feedback-admin.filter.php';
require_once 'init/filters/starfish-api.filter.php';